ODE Solver with Automatic Differentiation, in C++ Header Files
odelia-package.Rdodelia provides an ODE solver in C++ header files, using an adaptive-step Runge-Kutta 4-5 method, with an interface to R via Rcpp. ODE systems can be templated on their scalar type to support automatic differentiation, enabling exact gradients for parameter fitting.